@@ -1,5 +1,5 @@
 import torch
-from torch import Tensor, LongTensor
+from torch import LongTensor, Tensor
 
 from quaterion.distances import Distance
 from quaterion.eval.accumulators import PairAccumulator
