@@ -1,5 +1,7 @@
 from quaterion.loss.arcface_loss import ArcFaceLoss
+from quaterion.loss.circle_loss import CircleLoss
 from quaterion.loss.contrastive_loss import ContrastiveLoss
+from quaterion.loss.fast_ap_loss import FastAPLoss
 from quaterion.loss.group_loss import GroupLoss
 from quaterion.loss.multiple_negatives_ranking_loss import MultipleNegativesRankingLoss
 from quaterion.loss.online_contrastive_loss import OnlineContrastiveLoss
