@@ -1,6 +1,8 @@
 from quaterion.utils.utils import (
     get_anchor_negative_mask,
     get_anchor_positive_mask,
+    get_masked_maximum,
+    get_masked_minimum,
     get_triplet_mask,
     info_value_of_dtype,
     max_value_of_dtype,
